@@ -3,7 +3,7 @@ package App::CmdDispatch::Help;
 use warnings;
 use strict;
 
-our $VERSION = '0.3_01';
+our $VERSION = '0.1';
 
 sub new
 {
@@ -39,14 +39,12 @@ sub _extend_table_with_help
     my ( $commands ) = @_;
     $commands->{help} = {
         code     => \&_dispatch_help,
-        clue     => "help [command|alias]",
-        abstract => 'Display complete help',
+        synopsis => "help [command|alias]",
         help     => "Display help about commands and/or aliases. Limit display with the\nargument.",
     };
     $commands->{hint} = {
         code     => \&_dispatch_hint,
-        clue     => "hint [command|alias]",
-        abstract => 'Display command hints',
+        synopsis => "hint [command|alias]",
         help     => 'A list of commands and/or aliases. Limit display with the argument.',
     };
     return;
@@ -65,26 +63,10 @@ sub _dispatch_hint
 }
 
 sub _hint_string
-{
-    my ( $self, $cmd, $maxlen ) = @_;
-    my $desc = $self->_table->get_command( $cmd );
-    return '' unless $desc;
-    my $indent = ( $maxlen ? ' ' x ( 3 + $maxlen - length $desc->{clue} ) : '   ' );
-    return $desc->{clue} . ( $desc->{abstract} ? $indent . $desc->{abstract} : '' );
-}
-
-sub _clue_string
 {
     my ( $self, $cmd ) = @_;
     my $desc = $self->_table->get_command( $cmd );
-    return '' unless $desc;
-    return $desc->{clue};
-}
-
-sub _alias_hint
-{
-    my ($self, $alias) = @_;
-    return "$alias\t: " . $self->_table->get_alias( $alias );
+    return $desc ? $desc->{synopsis} : $desc;
 }
 
 sub _help_string
@@ -118,37 +100,21 @@ sub _list_aliases
     $self->_print( "\nAliases:\n" );
     foreach my $c ( $self->{owner}->alias_list() )
     {
-        $self->_print( $self->{indent_hint} . $self->_alias_hint( $c ) . "\n" );
+        $self->_print( "$self->{indent_hint}$c\t: " . $self->_table->get_alias( $c ) . "\n" );
     }
     return;
 }
 
 sub _is_missing { return !defined $_[0] || $_[0] eq ''; }
 
-sub _get_abstract_offset
-{
-    my ( $self ) = @_;
-
-    my $maxlen = 0;
-    my $len;
-    foreach my $cmd ( $self->_table->command_list() )
-    {
-        $len = length $self->_table->get_command( $cmd )->{clue};
-        $maxlen = $len if $len > $maxlen;
-    }
-    return $maxlen;
-}
-
 sub hint
 {
     my ( $self, $arg ) = @_;
 
     if( _is_missing( $arg ) )
     {
-        my $maxlen = $self->_get_abstract_offset();
         $self->_print( "\n$self->{pre_hint}\n" ) if $self->{pre_hint};
-        $self->_list_command(
-            sub { $self->{indent_hint}, $self->_hint_string( $_[0], $maxlen ), "\n"; } );
+        $self->_list_command( sub { $self->{indent_hint}, $self->_hint_string( $_[0] ), "\n"; } );
         $self->_list_aliases();
         $self->_print( "\n$self->{post_hint}\n" ) if $self->{post_hint};
         return;
@@ -160,12 +126,11 @@ sub hint
     }
     elsif( $self->_table->get_alias( $arg ) )
     {
-        $self->_print( "\n", $self->_alias_hint( $arg ), "\n" );
+        $self->_print( "\n$arg\t: ", $self->_table->get_alias( $arg ), "\n" );
     }
     elsif( $arg eq 'commands' )
     {
-        my $maxlen = $self->_get_abstract_offset();
-        $self->_list_command( sub { $self->{indent_hint}, $self->_hint_string( $_[0], $maxlen ), "\n"; } );
+        $self->_list_command( sub { $self->{indent_hint}, $self->_hint_string( $_[0] ), "\n"; } );
     }
     elsif( $arg eq 'aliases' )
     {
@@ -188,7 +153,7 @@ sub help
         $self->_print( "\n$self->{pre_help}\n" ) if $self->{pre_help};
         $self->_list_command(
             sub {
-                $self->{indent_hint}, $self->_clue_string( $_[0] ), "\n",
+                $self->{indent_hint}, $self->_hint_string( $_[0] ), "\n",
                     $self->_help_string( $_[0] ), "\n";
             }
         );
@@ -199,19 +164,19 @@ sub help
 
     if( $self->_table->get_command( $arg ) )
     {
-        $self->_print( "\n", $self->_clue_string( $arg ),
+        $self->_print( "\n", $self->_hint_string( $arg ),
             "\n", ( $self->_help_string( $arg ) || $self->{indent_help} . "No help for '$arg'" ),
             "\n" );
     }
     elsif( $self->_table->get_alias( $arg ) )
     {
-        $self->_print( "\n", $self->_alias_hint( $arg ), "\n" );
+        $self->_print( "\n$arg\t: ", $self->_table->get_alias( $arg ), "\n", );
     }
     elsif( $arg eq 'commands' )
     {
         $self->_list_command(
             sub {
-                $self->{indent_hint}, $self->_clue_string( $_[0] ), "\n",
+                $self->{indent_hint}, $self->_hint_string( $_[0] ), "\n",
                     $self->_help_string( $_[0] ), "\n";
             }
         );
@@ -234,9 +199,8 @@ sub normalize_command_help
     foreach my $cmd ( $table->command_list )
     {
         my $desc = $table->get_command( $cmd );
-        $desc->{clue} = $cmd unless defined $desc->{clue};
-        $desc->{hint} = ''   unless defined $desc->{hint};
-        $desc->{help} = ''   unless defined $desc->{help};
+        $desc->{synopsis} = $cmd unless defined $desc->{synopsis};
+        $desc->{help}     = ''   unless defined $desc->{help};
     }
     return;
 }
@@ -265,7 +229,7 @@ App::CmdDispatch::Help - Provide help functionality for the CmdDispatch module
 
 =head1 VERSION
 
-This document describes App::CmdDispatch::Help version 0.3_01
+This document describes App::CmdDispatch::Help version 0.1
 
 =head1 SYNOPSIS
 
@@ -298,7 +262,7 @@ from the description hash of each command.
 
 =over 4
 
-=item clue
+=item synopsis
 
 This text is a short blurb showing the format of the command.
 
