@@ -4,15 +4,12 @@ use warnings;
 use strict;
 use Term::ReadLine;
 
-our $VERSION = '0.3_01';
+our $VERSION = '0.1';
 
-my $term;
 sub new
 {
     my $class = shift;
-    $term ||= Term::ReadLine->new('CmdDispatch Shell');
-    $term->ornaments( 0 );
-    return bless { term => $term }, $class;
+    return bless {}, $class;
 }
 
 sub print
@@ -24,43 +21,16 @@ sub print
 sub readline
 {
     my ($self) = @_;
-    return $self->{term}->readline( '' );
+    return Term::ReadLine::readline();
 }
 
 sub prompt
 {
     my ($self, @in) = @_;
-    return $self->{term}->readline( @in );
+    $self->print( @in );
+    return $self->readline();
 }
 
-{
-    package App::CmdDispatch::MinimalIO;
-
-    sub new
-    {
-        my $class = @_;
-        return bless {}, $class;
-    }
-
-    sub print
-    {
-        my $self = shift;
-        return CORE::print @_;
-    }
-
-    sub readline
-    {
-        my ($self) = @_;
-        return CORE::readline;
-    }
-
-    sub prompt
-    {
-        my ($self, @in) = @_;
-        $self->print( @in );
-        return $self->readline();
-    }
-}
 1;
 __END__
 
@@ -71,7 +41,7 @@ App::CmdDispatch::IO - Abstract out the input and output for C<App::CmdDispatch>
 
 =head1 VERSION
 
-This document describes C<App::CmdDispatch::IO> version 0.3_01
+This document describes C<App::CmdDispatch::IO> version 0.1
 
 =head1 SYNOPSIS
 
